package info.bukova.isspst.filters;

import static info.bukova.isspst.StringUtils.not0ToStr;
import static info.bukova.isspst.StringUtils.nullStr;
import info.bukova.isspst.data.Address;

import org.hamcrest.Description;
import org.hamcrest.Factory;
import org.hamcrest.Matcher;
import org.hamcrest.TypeSafeMatcher;

public class AddressFilter implements Filter<Address> {
	
	private Address condAddr;
	
	public AddressFilter(Address condAddr) {
		this.condAddr = condAddr;
	}

	private static class AddrMatcher extends TypeSafeMatcher<Address> {

		private Address condAddress;
		
		public AddrMatcher(Address cond) {
			this.condAddress = cond;
		}
		
		@Override
		public void describeTo(Description desc) {
			desc.appendText("address matches");
		}

		@Override
		public boolean matchesSafely(Address item) {
			return nullStr(item.getCompany()).toLowerCase().contains(nullStr(condAddress.getCompany()).toLowerCase()) 
					&& nullStr(item.getCity()).toLowerCase().contains(nullStr(condAddress.getCity()).toLowerCase())
					&& nullStr(item.getContactName()).toLowerCase().contains(nullStr(condAddress.getContactName()).toLowerCase())
					&& nullStr(item.getStreet()).toLowerCase().contains(nullStr(condAddress.getStreet()).toLowerCase())
					&& not0ToStr(item.getIc()).startsWith(not0ToStr(condAddress.getIc()))
					&& nullStr(item.getHouseNumber()).startsWith(nullStr(condAddress.getHouseNumber()));
		}
		
		@Factory
		public static Matcher<Address> matchAddr(Address addr) {
			return new AddrMatcher(addr);
		}
	}
	
	@Override
	public AddrMatcher matcher() {
		return new AddrMatcher(condAddr);
	}

	@Override
	public String queryString() {
		// TODO query string
		return "";
	}

}
