package info.bukova.isspst.services;

import java.util.Date;

import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.transaction.annotation.Transactional;

import info.bukova.isspst.data.OwnedDataModel;
import info.bukova.isspst.data.User;

public class AbstractOwnedService<T extends OwnedDataModel> extends AbstractService<T> {
	
	@Override
	@Transactional
	public void add(T entity) {
		validate(entity);
		entity.setCreated(new Date());
		entity.setOwnedBy(getLoggedInUser());
		dao.add(entity);
	}
	
	@Override
	@Transactional
	public void update(T entity) {
		if (entity.getCreated() == null) {
			add(entity);
		} else {
			validate(entity);
			entity.setModifiedBy(getLoggedInUser());
			entity.setModified(new Date());
			dao.modify(entity);
		}
	}
	
	protected User getLoggedInUser() {
		return (User)SecurityContextHolder.getContext().getAuthentication().getPrincipal();
	}

}
