package info.bukova.isspst.services.users;

import org.hibernate.Query;
import org.springframework.security.authentication.encoding.PasswordEncoder;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.transaction.annotation.Transactional;

import info.bukova.isspst.data.Role;
import info.bukova.isspst.data.User;
import info.bukova.isspst.services.AbstractService;

public class UserServiceImpl extends AbstractService<User> implements UserService {

	private PasswordEncoder encoder;
	
	public void setEncoder(PasswordEncoder encoder) {
		this.encoder = encoder;
	}
	
	@Override
	@Transactional
	public UserDetails loadUserByUsername(String username)
			throws UsernameNotFoundException {
		
		Query q = dao.getQuery("from User user where user.username = :username");
		q.setString("username", username);
		User u = (User) q.uniqueResult();
		
		if (u == null)
			throw new UsernameNotFoundException("User " + username + " not found");
		
		return u;
	}

	@Override
	public void setPassword(User user, String password) {
		user.setPassword(encoder.encodePassword(password, user.getUsername()));
	}

	@Override
	public boolean hasRole(User user, String authority) {
		for (Role r : user.getAuthorities()) {
			if (r.getAuthority().equals(authority)) {
				return true;
			}
		}
		return false;
	}

	@Override
	@Transactional
	public void saveWithPwd(User user, String password) {
		this.setPassword(user, password);
		this.update(user); 
	}


}
