package info.bukova.isspst.ui;

import info.bukova.isspst.data.DataModel;
import info.bukova.isspst.services.Service;
import info.bukova.isspst.services.ValidationException;

import java.util.Map;

import org.zkoss.bind.annotation.BindingParam;
import org.zkoss.bind.annotation.Command;
import org.zkoss.bind.annotation.ExecutionArgParam;
import org.zkoss.bind.annotation.Init;
import org.zkoss.bind.annotation.NotifyChange;
import org.zkoss.zul.Messagebox;
import org.zkoss.zul.Window;

public class FormViewModel<T extends DataModel> {
	
	private T dataBean;
	private Map<String, String> errMessages;
	private Service<T> service;
	
	@Init
	public void init(@ExecutionArgParam("selected") T selected, @ExecutionArgParam("service") Service<T> service) {
		this.dataBean = selected;
		this.service = service;
	}
	
	public T getDataBean() {
		return dataBean;
	}
	
	@Command
	@NotifyChange("errMessages")
	public void save(@BindingParam("window") Window win) {
		try {
			doSave();
			win.detach();
		} catch (ValidationException e) {
			errMessages = e.getMessages();
			String classErr = errMessages.get("CLASS_ERR");
			
			if (classErr == null) {
				classErr = "";
			}
			
			Messagebox.show("Chyba validace", "Chyba", Messagebox.OK, Messagebox.ERROR);
		} catch (Exception e) {
			dataBean.setCreated(null);
			e.printStackTrace();
			Messagebox.show("Chyba při ukládání záznamu", "Chyba", Messagebox.OK, Messagebox.ERROR);
		}
	}

	public Map<String, String> getErrMessages() {
		return errMessages;
	}
	
	protected void setErrMesages(Map<String, String> msgs) {
		this.errMessages = msgs;
	}
	
	protected void doSave() {
		service.update(dataBean);
	}
	
	public boolean isCanSave() {
		return true;
	}

}
