package info.bukova.isspst.ui.users;

import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.zkoss.bind.annotation.Command;
import org.zkoss.bind.annotation.Init;
import org.zkoss.bind.annotation.NotifyChange;
import org.zkoss.zk.ui.select.annotation.WireVariable;

import info.bukova.isspst.data.User;
import info.bukova.isspst.services.users.RoleService;
import info.bukova.isspst.services.users.UserService;
import info.bukova.isspst.ui.FormViewModel;

public class UserForm extends FormViewModel<User> {
	
	@WireVariable
	private RoleService roleService;
	@WireVariable
	private UserService userService;
	private String retPasswd = "";
	private String password = "";
	private UserRoles userRoles;
	private boolean loginFree;
	
	@Init(superclass = true)
	public void init() {
		userRoles = new UserRoles(getDataBean(), roleService.getAll());
		loginFree = true;
	}

	public UserRoles getUserRoles() {
		return userRoles;
	}
	
	public String getRetPasswd() {
		return retPasswd;
	}

	@NotifyChange({"canSave", "pwMatches"})
	public void setRetPasswd(String retPasswd) {
		this.retPasswd = retPasswd;
	}

	public String getPassword() {
		return password;
	}

	@NotifyChange({"canSave", "pwMatches"})
	public void setPassword(String password) {
		this.password = password;
	}
	
	@Command
	@NotifyChange({"loginFree", "canSave"})
	public void checkLogin() {
		try {
			userService.loadUserByUsername(getDataBean().getUsername());
			loginFree = false;
		} catch(UsernameNotFoundException e) {
			loginFree = true;
		}
	}
	
	public boolean isPwMatches() {
		return password.equals(retPasswd);
	}
	
	public boolean isLoginFree() {
		return loginFree || isEdit();
	}
	
	public boolean isEdit() {
		return getDataBean().getCreated() != null;
	}
	
	@Override
	protected void doSave() {
		if (!password.isEmpty()) {
			userService.saveWithPwd(getDataBean(), this.password);
		} else {
			super.doSave();
		}
	}
	
	@Override
	public boolean isCanSave() {
		return password.equals(retPasswd) && isLoginFree() && getDataBean().getUsername() != null && !getDataBean().getUsername().isEmpty();
	}

}
